searchNodes=[{"doc":"DepMulti is a data structure for performing dependant asynchronous operations.To demonstrate the problem, image you have three asynchronous tasks:## [Task.async(fn -&gt; do_some_work() end), Task.async(fn -&gt; do_some_other_work() end), Task.async(fn -&gt; do_more_work() end), ] |&gt; Enum.map(&amp;Task.await/1)This works until you have a dependency / ordering issue. Say do_more_work must happen after do_some_work. At that point, you'll need to name each task and reference those names in other tasks that are dependant on them. If those dependant task needs data from a previous task, you'll also want pass those changes into the function.The API to solve this issue is based on Ecto.Multi(https://hexdocs.pm/ecto/Ecto.Multi.html), and specifically run/3 and run/5. The differences are:The tasks are executed asychronouslythe run methods take a list of dependencies and a timeoutthe changes passed into the function only include direct or indirect dependenciesExample iex&gt; DepMulti.new() ...&gt; |&gt; DepMulti.run(:step1, [], fn -&gt; ...&gt; {:ok, 1} ...&gt; end) ...&gt; |&gt; DepMulti.run(:step_2a, [dependencies: [:step_1], timeout: 5000], fn %{step_1: value} -&gt; ...&gt; {:ok, 2 + value} ...&gt; end) ...&gt; |&gt; DepMulti.run(:step_2b, [dependencies: [:step_1]], Map, :fetch, [:step_1]) ...&gt; |&gt; DepMulti.execute() {:ok, %{step_1: 1, step_2a: 3, step_2b: 1}}","ref":"DepMulti.html","title":"DepMulti","type":"module"},{"doc":"","ref":"DepMulti.html#execute/2","title":"DepMulti.execute/2","type":"function"},{"doc":"Returns an empty DepMulti struct.Exampleiex&gt; DepMulti.new() |&gt; DepMulti.to_list() []","ref":"DepMulti.html#new/0","title":"DepMulti.new/0","type":"function"},{"doc":"Adds a function to run as part of the multi.The function should return either {:ok, value} or {:error, value}, and receives the changes so far as the only argument.NOTE: The changes will only include direct or indirect dependenciesExampleDepMulti.run(multi, :write, [:image], fn %{image: image} -&gt; with :ok &lt;- File.write(image.name, image.contents) do {:ok, nil} end end)","ref":"DepMulti.html#run/4","title":"DepMulti.run/4","type":"function"},{"doc":"Adds a function to run as part of the multi.Similar to run/4, but allows to pass module name, function and arguments. The function should return either {:ok, value} or {:error, value}, and receives the rthe changes so far as the first argument (prepended to those passed in the call to the function).NOTE: The changes will only include direct or indirect dependencies","ref":"DepMulti.html#run/6","title":"DepMulti.run/6","type":"function"},{"doc":"Returns the list of operations stored in multi.","ref":"DepMulti.html#to_list/1","title":"DepMulti.to_list/1","type":"function"},{"doc":"","ref":"DepMulti.html#t:changes/0","title":"DepMulti.changes/0","type":"type"},{"doc":"","ref":"DepMulti.html#t:dependencies/0","title":"DepMulti.dependencies/0","type":"type"},{"doc":"","ref":"DepMulti.html#t:name/0","title":"DepMulti.name/0","type":"type"},{"doc":"","ref":"DepMulti.html#t:names/0","title":"DepMulti.names/0","type":"type"},{"doc":"","ref":"DepMulti.html#t:operations/0","title":"DepMulti.operations/0","type":"type"},{"doc":"","ref":"DepMulti.html#t:run/0","title":"DepMulti.run/0","type":"type"},{"doc":"","ref":"DepMulti.html#t:run_cmd/0","title":"DepMulti.run_cmd/0","type":"type"},{"doc":"","ref":"DepMulti.html#t:t/0","title":"DepMulti.t/0","type":"type"},{"doc":"DepMulti.Operation is a data structure for storing a steps data.","ref":"DepMulti.Operation.html","title":"DepMulti.Operation","type":"module"},{"doc":"","ref":"DepMulti.Operation.html#t:changes/0","title":"DepMulti.Operation.changes/0","type":"type"},{"doc":"","ref":"DepMulti.Operation.html#t:dependencies/0","title":"DepMulti.Operation.dependencies/0","type":"type"},{"doc":"","ref":"DepMulti.Operation.html#t:name/0","title":"DepMulti.Operation.name/0","type":"type"},{"doc":"","ref":"DepMulti.Operation.html#t:run/0","title":"DepMulti.Operation.run/0","type":"type"},{"doc":"","ref":"DepMulti.Operation.html#t:run_cmd/0","title":"DepMulti.Operation.run_cmd/0","type":"type"},{"doc":"","ref":"DepMulti.Operation.html#t:t/0","title":"DepMulti.Operation.t/0","type":"type"},{"doc":"DepMulti.ProcessingOperation is a data structure for storing a steps data.","ref":"DepMulti.ProcessingOperation.html","title":"DepMulti.ProcessingOperation","type":"module"},{"doc":"","ref":"DepMulti.ProcessingOperation.html#t:t/0","title":"DepMulti.ProcessingOperation.t/0","type":"type"},{"doc":"","ref":"DepMulti.Runner.html","title":"DepMulti.Runner","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"DepMulti.Runner.html#child_spec/1","title":"DepMulti.Runner.child_spec/1","type":"function"},{"doc":"","ref":"DepMulti.Runner.html#failure/2","title":"DepMulti.Runner.failure/2","type":"function"},{"doc":"Callback implementation for GenServer.init/1.","ref":"DepMulti.Runner.html#init/1","title":"DepMulti.Runner.init/1","type":"function"},{"doc":"","ref":"DepMulti.Runner.html#start_link/1","title":"DepMulti.Runner.start_link/1","type":"function"},{"doc":"","ref":"DepMulti.Runner.html#success/2","title":"DepMulti.Runner.success/2","type":"function"},{"doc":"","ref":"DepMulti.RunnerSupervisor.html","title":"DepMulti.RunnerSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"DepMulti.RunnerSupervisor.html#child_spec/1","title":"DepMulti.RunnerSupervisor.child_spec/1","type":"function"},{"doc":"","ref":"DepMulti.RunnerSupervisor.html#execute/4","title":"DepMulti.RunnerSupervisor.execute/4","type":"function"},{"doc":"Callback implementation for DynamicSupervisor.init/1.","ref":"DepMulti.RunnerSupervisor.html#init/1","title":"DepMulti.RunnerSupervisor.init/1","type":"function"},{"doc":"","ref":"DepMulti.RunnerSupervisor.html#start_link/1","title":"DepMulti.RunnerSupervisor.start_link/1","type":"function"},{"doc":"","ref":"DepMulti.Server.html","title":"DepMulti.Server","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"DepMulti.Server.html#child_spec/1","title":"DepMulti.Server.child_spec/1","type":"function"},{"doc":"","ref":"DepMulti.Server.html#execute/2","title":"DepMulti.Server.execute/2","type":"function"},{"doc":"Callback implementation for GenServer.init/1.","ref":"DepMulti.Server.html#init/1","title":"DepMulti.Server.init/1","type":"function"},{"doc":"","ref":"DepMulti.Server.html#start_link/1","title":"DepMulti.Server.start_link/1","type":"function"},{"doc":"","ref":"DepMulti.Worker.html","title":"DepMulti.Worker","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"DepMulti.Worker.html#child_spec/1","title":"DepMulti.Worker.child_spec/1","type":"function"},{"doc":"Callback implementation for GenServer.init/1.","ref":"DepMulti.Worker.html#init/1","title":"DepMulti.Worker.init/1","type":"function"},{"doc":"","ref":"DepMulti.Worker.html#runner_failure/4","title":"DepMulti.Worker.runner_failure/4","type":"function"},{"doc":"","ref":"DepMulti.Worker.html#runner_success/4","title":"DepMulti.Worker.runner_success/4","type":"function"},{"doc":"","ref":"DepMulti.Worker.html#runner_terminate/4","title":"DepMulti.Worker.runner_terminate/4","type":"function"},{"doc":"","ref":"DepMulti.Worker.html#start_link/1","title":"DepMulti.Worker.start_link/1","type":"function"},{"doc":"","ref":"DepMulti.WorkerSupervisor.html","title":"DepMulti.WorkerSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"DepMulti.WorkerSupervisor.html#child_spec/1","title":"DepMulti.WorkerSupervisor.child_spec/1","type":"function"},{"doc":"","ref":"DepMulti.WorkerSupervisor.html#execute/4","title":"DepMulti.WorkerSupervisor.execute/4","type":"function"},{"doc":"Callback implementation for DynamicSupervisor.init/1.","ref":"DepMulti.WorkerSupervisor.html#init/1","title":"DepMulti.WorkerSupervisor.init/1","type":"function"},{"doc":"","ref":"DepMulti.WorkerSupervisor.html#start_link/1","title":"DepMulti.WorkerSupervisor.start_link/1","type":"function"},{"doc":"DepMultiTODO: Add description","ref":"readme.html","title":"DepMulti","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding dep_multi to your list of dependencies in mix.exs:def deps do [ {:dep_multi, &quot;~&gt; 0.1.0&quot;} ] endDocumentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/dep_multi.Syntax Inspiration - Ecto.Multi Supervsor Strategy","ref":"readme.html#installation","title":"DepMulti - Installation","type":"extras"},{"doc":"v 0.1.2 (2020-10-22)PR#6 correctly handle exceptionsv 0.1.1 (2020-10-13)PR#5 when 'shutdown' option is used set stop timeout of 5000 (instead of :infinity)v 0.1.0 (2020-09-28)Initial Release","ref":"changelog.html","title":"v 0.1.2 (2020-10-22)","type":"extras"}]